Module error

Module error 

SDK Error Types

This module provides comprehensive error handling for the Tensorlake Cloud SDK. It includes a general SdkError type that encompasses all possible error scenarios across the different clients, including authentication and authorization errors.

Enums

SdkError
The main error type for the Tensorlake Cloud SDK.