SdkError

Enum SdkError 

pub enum SdkError {
Show 14 variants Applications(ApplicationsError), Authentication(String), Authorization(String), Http(Error), Middleware(Error), Images(ImagesError), InvalidHeaderValue(String), ClientError(String), Io(Error), Json(Error), JsonWithError(Error<Error>), Secrets(SecretsError), ServerError { status: StatusCode, message: String, }, EventSourceError(String),
}
The main error type for the Tensorlake Cloud SDK.

This enum encompasses all possible errors that can occur when using the SDK, including client-specific errors, authentication issues, and general HTTP errors.

Variants



Applications(ApplicationsError)

Errors specific to the Applications client



Authentication(String)

Authentication error (HTTP 401)



Authorization(String)

Authorization error (HTTP 403)



Http(Error)

General HTTP errors



Middleware(Error)

Reqwest middleware errors



Images(ImagesError)

Errors specific to the Images client



InvalidHeaderValue(String)

Invalid header value during client initialization



ClientError(String)

Client configuration error



Io(Error)

General IO errors



Json(Error)

JSON serialization/deserialization errors



JsonWithError(Error<Error>)

JSON serialization/deserialization errors



Secrets(SecretsError)

Errors specific to the Secrets client



ServerError

Server returned an error status

Fields

status: StatusCode
message: String


EventSourceError(String)

EventSource (SSE) stream error