pub struct ImagesClient { /* private fields */ }Expand description
A client for managing image builds in Tensorlake Cloud.
Implementations
Sourceimpl ImagesClient
impl ImagesClient
pub fn new(client: Client) -> Self
Sourcepub async fn build_image(
&self,
request: ImageBuildRequest,
) -> Result<ImageBuildResult, SdkError>
pub async fn build_image( &self, request: ImageBuildRequest, ) -> Result<ImageBuildResult, SdkError>
Build a container image, poll for completion, and return the result.
pub async fn create_application_build( &self, build_service_path: &str, request: &CreateApplicationBuildRequest, image_contexts: &[ApplicationBuildContext], ) -> Result<Traced<ApplicationBuildResponse>, SdkError>
pub async fn application_build_info( &self, build_service_path: &str, application_build_id: &str, ) -> Result<Traced<ApplicationBuildResponse>, SdkError>
pub async fn cancel_application_build( &self, build_service_path: &str, application_build_id: &str, ) -> Result<Traced<ApplicationBuildResponse>, SdkError>
pub async fn list_builds( &self, request: &ListBuildsRequest, ) -> Result<Traced<Page<BuildListResponse>>, SdkError>
pub async fn cancel_build( &self, request: &CancelBuildRequest, ) -> Result<Traced<()>, SdkError>
pub async fn get_build_info( &self, request: &GetBuildInfoRequest, ) -> Result<Traced<BuildInfoResponse>, SdkError>
pub async fn stream_logs( &self, request: &StreamLogsRequest, ) -> Result<Traced<Pin<Box<dyn Stream<Item = Result<LogEntry, SdkError>> + Send>>>, SdkError>